@@ -51,18 +51,36 @@ fn get_extension_from_filename(filename: &str) -> Option<&str> {
 /// was received as part of `multipart/*` parsing.
 #[derive(Debug)]
 pub struct FilePart {
-    pub file_name: Option<String>,
+    file_name: Option<String>,
     /// The headers of the part
-    pub headers: HeaderMap,
+    headers: HeaderMap,
     /// A temporary file containing the file content
-    pub path: PathBuf,
+    path: PathBuf,
     /// Optionally, the size of the file.  This is filled when multiparts are parsed, but is
     /// not necessary when they are generated.
-    pub size: Option<usize>,
+    size: Option<usize>,
     // The temporary directory the upload was put into, saved for the Drop trait
     temp_dir: Option<PathBuf>,
 }
 impl FilePart {
+    pub fn file_name(&self) -> Option<&str> {
+        self.file_name.as_deref()
+    }
+    pub fn file_name_mut(&mut self) -> Option<&mut String> {
+        self.file_name.as_mut()
+    }
+    pub fn headers(&self) -> &HeaderMap {
+        &self.headers
+    }
+    pub fn headers_mut(&mut self) -> &mut HeaderMap {
+        &mut self.headers
+    }
+    pub fn path(&self) -> &PathBuf {
+        &self.path
+    }
+    pub fn size(&self) -> Option<usize> {
+        self.size
+    }
     /// If you do not want the file on disk to be deleted when Self drops, call this
     /// function.  It will become your responsibility to clean up.
     pub fn do_not_delete_on_drop(&mut self) {
@@ -99,10 +117,6 @@ impl FilePart {
             temp_dir,
         })
     }
-
-    pub fn file_name(&self) -> Option<&str> {
-        self.file_name.as_deref()
-    }
 }
 impl Drop for FilePart {
     fn drop(&mut self) {
@@ -117,7 +131,7 @@ impl Drop for FilePart {
     }
 }
 
-/// Parse MIME `multipart/form-data` information from a stream as a `FormData`.
+/// Parse MIME `multipart/*` information from a stream as a `FormData`.
 pub async fn read_form_data(headers: &HeaderMap, body: Body) -> Result<FormData, ReadError> {
     match headers.get(header::CONTENT_TYPE) {
         Some(ctype) if ctype == "application/x-www-form-urlencoded" => {
@@ -126,7 +140,7 @@ pub async fn read_form_data(headers: &HeaderMap, body: Body) -> Result<FormData,
             form_data.fields = form_urlencoded::parse(data.as_ref()).into_owned().collect();
             Ok(form_data)
         }
-        Some(ctype) if ctype.to_str().unwrap_or("").starts_with("multipart/form-data") => {
+        Some(ctype) if ctype.to_str().unwrap_or("").starts_with("multipart/") => {
             let mut form_data = FormData::new();
             if let Some(boundary) = headers
                 .get(header::CONTENT_TYPE)
@@ -136,12 +150,10 @@ pub async fn read_form_data(headers: &HeaderMap, body: Body) -> Result<FormData,
                 let mut multipart = Multipart::new(body, boundary);
                 while let Some(mut field) = multipart.next_field().await? {
                     if let Some(name) = field.name().map(|s| s.to_owned()) {
-                        if let Some(content_type) = field.headers().get(header::CONTENT_TYPE) {
-                            if content_type.to_str().unwrap_or_default().starts_with("text/") {
-                                form_data.fields.insert(name, field.text().await?);
-                            } else {
-                                form_data.files.insert(name, FilePart::create(&mut field).await?);
-                            }
+                        if field.headers().get(header::CONTENT_TYPE).is_some() {
+                            form_data.files.insert(name, FilePart::create(&mut field).await?);
+                        } else {
+                            form_data.fields.insert(name, field.text().await?);
                         }
                     }
                 }
