@@ -9,7 +9,7 @@ use async_compression::tokio::bufread::{BrotliDecoder, DeflateDecoder, GzipDecod
 use bytes::{BufMut, Bytes, BytesMut};
 use cookie::{Cookie, CookieJar};
 use encoding_rs::{Encoding, UTF_8};
-use futures_util::{Stream, StreamExt, TryStreamExt};
+use futures_util::stream::{Stream, StreamExt, TryStreamExt};
 use http::version::Version;
 use mime::Mime;
 use serde::de::DeserializeOwned;
@@ -30,11 +30,7 @@ pub enum Body {
 }
 impl Body {
     pub fn is_empty(&self) -> bool {
-        if let Body::Empty = *self {
-            true
-        } else {
-            false
-        }
+        matches!(*self, Body::Empty)
     }
     pub async fn take_json<T: DeserializeOwned>(&mut self) -> crate::Result<T> {
         let full = self.take_bytes().await?;
@@ -165,7 +161,7 @@ impl Response {
         ) = res.into_parts();
 
         // Set the request cookies, if they exist.
-        let cookies = if let Some(header) = headers.get("Cookie") {
+        let cookies = if let Some(header) = headers.get(header::SET_COOKIE) {
             let mut cookie_jar = CookieJar::new();
             if let Ok(header) = header.to_str() {
                 for cookie_str in header.split(';').map(|s| s.trim()) {
@@ -299,6 +295,10 @@ impl Response {
     pub fn cookies(&self) -> &CookieJar {
         &self.cookies
     }
+    #[inline]
+    pub fn cookies_mut(&mut self) -> &mut CookieJar {
+        &mut self.cookies
+    }
     pub fn header_cookies(&self) -> Vec<Cookie<'_>> {
         let mut cookies = vec![];
         for header in self.headers().get_all(header::SET_COOKIE).iter() {
@@ -311,24 +311,6 @@ impl Response {
         cookies
     }
 
-    #[inline]
-    pub fn get_cookie<T>(&self, name: T) -> Option<&Cookie<'static>>
-    where
-        T: AsRef<str>,
-    {
-        self.cookies.get(name.as_ref())
-    }
-    #[inline]
-    pub fn add_cookie(&mut self, cookie: Cookie<'static>) {
-        self.cookies.add(cookie);
-    }
-    #[inline]
-    pub fn remove_cookie<T>(&mut self, name: T)
-    where
-        T: Into<Cow<'static, str>>,
-    {
-        self.cookies.remove(Cookie::named(name));
-    }
     #[inline]
     pub fn status_code(&self) -> Option<StatusCode> {
         self.status_code
@@ -358,7 +340,6 @@ impl Response {
         self.commit();
     }
 
-    #[inline]
     pub fn render_json<T: Serialize>(&mut self, data: &T) {
         let mut cache = Cache::with_capacity(128);
         match serde_json::to_writer(&mut cache, data) {
@@ -580,11 +561,14 @@ impl Write for Cache {
 
 #[cfg(test)]
 mod test {
-    use super::Body;
     use bytes::BytesMut;
+    use cookie::Cookie;
     use futures_util::stream::{iter, StreamExt};
+    use serde::Deserialize;
     use std::error::Error;
 
+    use super::*;
+
     #[test]
     fn test_body_empty() {
         let body = Body::Bytes(BytesMut::from("hello"));
@@ -619,4 +603,30 @@ mod test {
 
         assert_eq!("hello world", &result)
     }
+    #[tokio::test]
+    async fn test_others() {
+        let mut response = Response::from_hyper(
+            hyper::Response::builder()
+                .header("set-cookie", "lover=dog")
+                .body("response body".into())
+                .unwrap(),
+        );
+        assert_eq!(response.header_cookies().len(), 1);
+        response.cookies_mut().add(Cookie::new("money", "sh*t"));
+        assert_eq!(response.cookies().get("money").unwrap().value(), "sh*t");
+        response.commit();
+        assert_eq!(response.header_cookies().len(), 2);
+        assert_eq!(response.take_bytes().await.unwrap().len(), b"response body".len());
+
+        #[derive(Deserialize, Eq, PartialEq, Debug)]
+        struct User {
+            name: String,
+        }
+
+        let mut response = Response::from_hyper(hyper::Response::builder().body(r#"{"name": "jobs"}"#.into()).unwrap());
+        assert_eq!(
+            response.take_json::<User>().await.unwrap(),
+            User { name: "jobs".into() }
+        );
+    }
 }
