@@ -6,7 +6,7 @@ pub struct MethodFilter(pub Method);
 
 impl Filter for MethodFilter {
     #[inline]
-    fn filter(&self, req: &mut Request, _path: &mut PathState) -> bool {
+    fn filter(&self, req: &mut Request, _state: &mut PathState) -> bool {
         req.method() == self.0
     }
 }
